from setuptools import setup

setup(name='tag2bio',
    version='0.2',
    description='A package created for translating tag formatted text to BIO formatted text.',
    packages=['tag2bio'],
    zip_safe=False
)